@@ -2,5 +2,5 @@
 
 __all__=['config', 'configfile', 'filecollection', 'filelist',
          'library', 'libraryview', 'organize', 'progress',
-         'serialize', 'sort', 'status', 'tageditor', 'tags',
+         'serialize', 'sort', 'status', 'tags',
          'treemodel', 'undo']
